# Generated by roxygen2: do not edit by hand

S3method(as.character,st_filter)
S3method(c,st_filter)
S3method(format,st_filter)
S3method(print,st_filter)
export(calculate_yoy_growth)
export(example_sensortower_data)
export(format_arpu)
export(format_currency)
export(format_downloads)
export(format_large_number)
export(format_market_share)
export(format_percent)
export(format_retention)
export(format_users)
export(lookup_category_names)
export(st_active_users)
export(st_analyze_filter)
export(st_api_diagnostics)
export(st_app)
export(st_app_details)
export(st_app_enriched)
export(st_app_info)
export(st_app_lookup)
export(st_app_tag)
export(st_apps)
export(st_batch_app_lookup)
export(st_batch_metrics)
export(st_build_filter_url)
export(st_build_web_url)
export(st_cache_info)
export(st_categories)
export(st_category_rankings)
export(st_clear_app_cache)
export(st_clear_id_cache)
export(st_combine_filters)
export(st_compare_filter_results)
export(st_create_simple_filter)
export(st_custom_fields_filter)
export(st_custom_fields_filter_by_id)
export(st_custom_fields_values)
export(st_demographics)
export(st_discover_fields)
export(st_extract_filter_id)
export(st_extract_url_params)
export(st_facets_metrics)
export(st_filter)
export(st_filter_by_date)
export(st_filter_by_genre)
export(st_filter_by_monetization)
export(st_filter_by_publisher)
export(st_filter_by_sdk)
export(st_game_summary)
export(st_generate_example_filter_ids)
export(st_get_app_names)
export(st_get_filter_collection)
export(st_get_filtered_apps)
export(st_get_unified_mapping)
export(st_gt_dashboard)
export(st_is_valid_filter_id)
export(st_market_metrics)
export(st_metrics)
export(st_parse_web_url)
export(st_publisher_apps)
export(st_publisher_portfolio)
export(st_rankings)
export(st_ratings_facets)
export(st_retention)
export(st_retention_facets)
export(st_reviews_by_rating_facets)
export(st_sales_report)
export(st_session_metrics)
export(st_smart_metrics)
export(st_test_filter)
export(st_top_charts)
export(st_top_publishers)
export(st_unified_sales_report)
export(st_yoy_metrics)
import(dplyr)
import(tidyr)
importFrom(dplyr,"%>%")
importFrom(dplyr,all_of)
importFrom(dplyr,any_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,coalesce)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,lag)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dplyr,transmute)
importFrom(glue,glue)
importFrom(graphics,title)
importFrom(httr,GET)
importFrom(httr,add_headers)
importFrom(httr,content)
importFrom(httr,http_error)
importFrom(httr,http_status)
importFrom(httr,status_code)
importFrom(httr,stop_for_status)
importFrom(httr2,req_body_json)
importFrom(httr2,req_error)
importFrom(httr2,req_headers)
importFrom(httr2,req_method)
importFrom(httr2,req_perform)
importFrom(httr2,req_retry)
importFrom(httr2,req_timeout)
importFrom(httr2,req_url_path_append)
importFrom(httr2,req_url_query)
importFrom(httr2,req_user_agent)
importFrom(httr2,request)
importFrom(httr2,resp_body_raw)
importFrom(httr2,resp_body_string)
importFrom(httr2,resp_check_status)
importFrom(httr2,resp_status)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(lubridate,ceiling_date)
importFrom(lubridate,day)
importFrom(lubridate,days)
importFrom(lubridate,floor_date)
importFrom(lubridate,month)
importFrom(lubridate,year)
importFrom(purrr,map)
importFrom(purrr,map2_chr)
importFrom(purrr,map_chr)
importFrom(purrr,map_df)
importFrom(purrr,map_int)
importFrom(rlang,"%||%")
importFrom(rlang,.data)
importFrom(rlang,`%||%`)
importFrom(rlang,abort)
importFrom(rlang,sym)
importFrom(rlang,warn)
importFrom(stats,na.omit)
importFrom(stats,runif)
importFrom(stats,setNames)
importFrom(stringr,str_detect)
importFrom(stringr,str_to_lower)
importFrom(tibble,as_tibble)
importFrom(tibble,as_tibble_row)
importFrom(tibble,tibble)
importFrom(tidyr,nest)
importFrom(tidyr,unnest)
importFrom(utils,URLencode)
importFrom(utils,data)
importFrom(utils,head)
importFrom(utils,tail)
