% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/st_custom_fields_workflow.R
\name{st_analyze_filter}
\alias{st_analyze_filter}
\title{Analyze Custom Filter Performance}
\usage{
st_analyze_filter(
  filter_id,
  measure = "DAU",
  regions = "US",
  top_n = 10,
  auth_token = NULL
)
}
\arguments{
\item{filter_id}{Character. The custom fields filter ID to analyze}

\item{measure}{Character. Metric to analyze: "DAU", "revenue", or "units"}

\item{regions}{Character vector. Region codes (default "US")}

\item{top_n}{Integer. Number of top apps to show (default 10)}

\item{auth_token}{Optional. Character string. Your Sensor Tower API token.}
}
\value{
A list containing summary statistics and top apps
}
\description{
Provides a summary analysis of apps matching a custom filter, including
top performers, growth metrics, and category breakdown.
}
