% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/constants.R
\docType{data}
\name{METRIC_MAPPING}
\alias{METRIC_MAPPING}
\title{Metric Mapping for Custom Tags}
\format{
An object of class \code{character} of length 60.
}
\usage{
METRIC_MAPPING
}
\description{
Maps raw API field names (from entities.custom_tags or aggregate_tags)
to cleaner, user-friendly column names.
}
\keyword{internal}
