% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/custom_filter_utils.R
\name{extract_custom_filter_params}
\alias{extract_custom_filter_params}
\title{Extract Custom Filter from URL Parameters}
\usage{
extract_custom_filter_params(params)
}
\arguments{
\item{params}{List. Parameters from st_parse_web_url()}
}
\value{
List with custom_fields_filter_id and custom_tags_mode (or NULLs)
}
\description{
Helper to extract custom filter parameters from parsed URL parameters
}
\keyword{internal}
