% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/st_smart_metrics.R
\name{st_cache_info}
\alias{st_cache_info}
\title{Show App ID Cache Statistics}
\usage{
st_cache_info()
}
\value{
No return value, called for side effects (displaying cache statistics).
}
\description{
Display information about the current app ID cache
}
