% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/custom_filter_utils.R
\name{get_custom_filter_docs}
\alias{get_custom_filter_docs}
\title{Get Custom Filter Documentation}
\usage{
get_custom_filter_docs()
}
\value{
Character vector with roxygen2 parameter documentation
}
\description{
Returns standardized documentation for custom filter parameters
}
\keyword{internal}
