% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/st_url_parser.R
\name{st_build_web_url}
\alias{st_build_web_url}
\title{Create Sensor Tower Web URL from Parameters}
\usage{
st_build_web_url(
  os = "unified",
  measure = "revenue",
  category = NULL,
  regions = "US",
  start_date = NULL,
  end_date = NULL,
  custom_fields_filter_id = NULL,
  custom_tags_mode = NULL,
  ...
)
}
\arguments{
\item{os}{Operating system}

\item{measure}{Measure type}

\item{category}{Category ID}

\item{regions}{Region codes (converted to country parameters)}

\item{start_date}{Start date}

\item{end_date}{End date}

\item{custom_fields_filter_id}{Custom filter ID}

\item{custom_tags_mode}{Custom tags mode}

\item{...}{Additional parameters}
}
\value{
Character string URL
}
\description{
Builds a Sensor Tower web interface URL from API parameters.
This is the reverse of st_parse_web_url().
}
